<?php

namespace Kylin\Notification\Facades;

use Illuminate\Support\Facades\Facade;

class KylinNotification extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-notification';
    }
}
